// proxy.h
// $Id: proxy.h,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
// masashi shimakura

#ifndef _SITAR_PROXY_H_
  #define _SITAR_PROXY_H_

  #include"config.h"

  #define CL_VAR "sitar_proxy-1.1.13"

  #define BUF_LEN 1024
  #define BUF_DEFLEN 128
  #define BUF_MAX 1024 * 1024 * 2

  #define TIME_LEN 128
  #define INT_VAL 30

  /* debug option */
//  #define PROXY_BUG

  struct buf_data{
     char ** getdata;
     };

  struct my_sock{
     pthread_t * pt;
     int max_count;
     int fdno;
     int * fdstat;
     struct {
        unsigned int my_addrlen;
        int * sk;
        int ls;
        char * ip_addr;
        char * ch_port;
        int port;
        struct sockaddr_in my_addr;
        } in;
     struct {
        int * sk;
        char * ip_addr;
        char * ch_port;
        int port;  
        struct sockaddr_in my_addr;
        } out;
     };

  struct exec_id {
     int    uid;
     };

  #include "./prototype.h"

#endif 

 
